==> nocc-1.9.5.txz: usr/local/www/nocc/lang/it.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: it.php 2621 2014-06-23 12:43:39Z siebrand $
 */
/** Italian (italiano)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Beta16
 * @author Darth Kule
 * @author Francesco Andreozzi <ozzo@lauratiamo.it>
 * @author Gianfranco
 * @author Guido Venturini <guido@technojuice.com>
 * @author Nastoshka
 * @author Rippitippi
 */

$lang_locale = 'it_IT.UTF-8';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Campo di login vuoto';
$err_passwd_empty = 'Non hai digitato la password';
$alt_delete = 'Elimina il messaggio selezionato';
$alt_delete_one = 'Elimina il messaggio';
$alt_new_msg = 'Nuovo messaggio';
$alt_reply = 'Rispondi al Mittente';
$alt_reply_all = 'Rispondi a tutti';
$alt_forward = 'Inoltra';
$alt_next = 'Prossimo';
$alt_prev = 'Precedente';
$title_next_page = 'Pagina successiva';
$title_prev_page = 'Pagina precedente';
$title_next_msg = 'Prossimo';
$title_prev_msg = 'Precedente';
$html_theme_label = 'Tema:';
$html_welcome = 'Benvenuto su %1$s';
$html_login = 'Accedi';
$html_user_label = 'Nome utente:';
$html_passwd_label = 'Password:';
$html_submit = 'Ok';
$html_help = 'Aiuto';
$html_server_label = 'Server:';
$html_wrong = 'Login o password non corretti';
$html_retry = 'Riprova';
$html_remember = 'Ricorda Impostazioni';
$html_lang_label = 'Lingua:';
$html_msgperpage_label = 'Messaggi per pagina:';
$html_preferences = 'Preferenze';
$html_full_name_label = 'Nome completo:';
$html_email_address_label = 'Indirizzo e-mail:';
$html_bccself = 'Manda una copia nascosta a me stesso';
$html_hide_addresses = 'Nascondi indirizzo';
$html_outlook_quoting = 'Quote Outlook-style';
$html_reply_to = 'Rispondi a';
$html_reply_to_label = 'Rispondi a:';
$html_use_signature = 'Usa la firma';
$html_signature = 'Firma';
$html_signature_label = 'Firma:';
$html_reply_leadin_label = 'Prefisso per risposte:';
$html_prefs_updated = 'Preferenze aggiornate';
$html_manage_folders_link = 'Configura Cartelle IMAP';
$html_manage_filters_link = 'Configura Filtri Email';
$html_use_graphical_smilies = 'Usa smilies grafici';
$html_sent_folder_label = 'Copia email inviate nella cartella predefinita';
$html_trash_folder_label = 'Sposta i messaggi cancellati nella cartella predefinita';
$html_colored_quotes = 'Citazioni a colori';
$html_display_struct = 'Mostra testo strutturato';
$html_send_html_mail = 'Invia messaggi in formato HTML';
$html_folders = 'Cartelle';
$html_folders_create_failed = 'La cartella non può essere creata!';
$html_folders_sub_failed = 'Impossibile connettersi alla cartella!';
$html_folders_unsub_failed = 'Impossibile disconnettersi dalla cartella!';
$html_folders_rename_failed = 'La cartella non può essere rinominata!';
$html_folders_updated = 'Cartelle aggiornate';
$html_folder_subscribe = 'Connettiti a';
$html_folder_rename = 'Rinomina';
$html_folder_create = 'Crea una nuova cartella con nome';
$html_folder_remove = 'Disconnettiti da';
$html_folder_delete = 'Elimina';
$html_folder_to = 'a';
$html_filter_remove = 'Cancella';
$html_filter_body = 'Corpo del messaggio';
$html_filter_subject = 'Soggetto';
$html_filter_to = 'Campo To';
$html_filter_cc = 'Campo Cc';
$html_filter_from = 'Campo From';
$html_filter_change_tip = 'Sovrascrivere direttamente un filtro per cambiarlo.';
$html_reapply_filters = 'Riapplica tutti i filtri';
$html_filter_contains = 'contiene';
$html_filter_name = 'Nome filtro';
$html_filter_action = 'Azione filtro';
$html_filter_moveto = 'Sposta in';
$html_select_one = '--Seleziona Uno--';
$html_and = 'e';
$html_new_msg_in = 'Nuovo messaggio in';
$html_or = 'o';
$html_move = 'Sposta';
$html_copy = 'Copia';
$html_messages_to = 'Messaggi selezionati in';
$html_gotopage = 'Vai alla pagina';
$html_gotofolder = 'Vai alla Cartella';
$html_other_folders = 'Lista Cartelle';
$html_page = 'Pagina';
$html_of = 'di';
$html_view_header = 'Mostra intestazione';
$html_remove_header = 'Nascondi intestazione';
$html_inbox = 'Posta in Arrivo';
$html_new_msg = 'Scrivi';
$html_reply = 'Rispondi';
$html_reply_short = 'Risposta:';
$html_reply_all = 'Rispondi a tutti';
$html_forward = 'Inoltra';
$html_forward_short = 'Inoltra:';
$html_forward_info = 'Il messaggio inoltrato sarà inviato come allegato a questo messaggio.';
$html_delete = 'Cancella';
$html_new = 'Nuovo';
$html_mark = 'Cancella';
$html_att_label = 'Allegato:';
$html_atts_label = 'Allegati:';
$html_unknown = '[sconosciuto]';
$html_part_x = 'Parte %s';
$html_attach = 'Allega';
$html_attach_forget = 'Devi allegare il file prima di inviare il messaggio !';
$html_attach_delete = 'Elimina i files selezionati';
$html_attach_none = 'Devi selezionare un file da allegare!';
$html_sort_by = 'Ordina per';
$html_sort = 'Ordina';
$html_from = 'da';
$html_from_label = 'Da:';
$html_subject = 'Oggetto';
$html_subject_label = 'Oggetto:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Invia';
$html_wrote = 'scritto';
$html_quote_wrote = 'Il %1$s %2$s, %3$s ha scritto:';
$html_size = 'Dimensione';
$html_totalsize = 'Dimensione Totale';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nome del file';
$html_to = 'A';
$html_to_label = 'A:';
$html_cc = 'Per conoscenza';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Senza Oggetto';
$html_send = 'Invia';
$html_cancel = 'Annulla';
$html_no_mail = 'Non vi sono nuovi messaggi.';
$html_logout = 'Esci';
$html_msg = 'Messaggio';
$html_msgs = 'Messaggi';
$html_configuration = 'Questo server non è configurato correttamente!';
$html_priority = 'Priorità';
$html_priority_label = 'Priorità:';
$html_lowest = 'Più bassa';
$html_low = 'Bassa';
$html_normal = 'Normale';
$html_high = 'Alta';
$html_highest = 'Più alta';
$html_flagged = 'Segnato';
$html_spam = 'Spam';
$html_spam_warning = 'Questo messaggio è stato classificato come spam.';
$html_receipt = 'Richiedi conferma di recapito';
$html_select = 'Seleziona';
$html_select_all = 'Inverti Selezione';
$html_select_contacts = 'Selezionare i contatti';
$html_loading_image = 'Apertura immagine';
$html_send_confirmed = 'La tua e-mail è stata accettata per la consegna';
$html_no_sendaction = 'Nessuna azione specificata. Prova ad abilitare i JavaScript.';
$html_error_occurred = 'Si è verificato un errore';
$html_prefs_file_error = 'Impossibile aprire per la modifica il file delle preferenze.';
$html_wrap = 'Numero di caratteri per l\'andata a capo dei messaggi in uscita:';
$html_wrap_none = 'Nessuna andata a capo';
$html_usenet_separator = 'Separatore ("-- \n") prima della firma';
$html_mark_as = 'Contrassegna come';
$html_read = 'letto';
$html_unread = 'non letto';
$html_encoding_label = 'Codifica dei caratteri:';
$html_add = 'Nuovo';
$html_contacts = '%1$s Contatti';
$html_modify = 'Modifica';
$html_back = 'Indietro';
$html_contact_add = 'Aggiungi nuovo contatto';
$html_contact_mod = 'Modifica un contatto';
$html_contact_first = 'Nome';
$html_contact_last = 'Cognome';
$html_contact_nick = 'Nick';
$html_contact_mail = 'Email';
$html_contact_list = 'Lista dei Contatti di %1$s';
$html_contact_del = 'dalla lista dei contatti';
$html_contact_count = '%1$d Contatti';
$html_contact_err1 = 'Il numero massimo dei contatti è "%1$d"';
$html_contact_err2 = 'Non puoi aggiungere altri contatti';
$html_contact_err3 = 'Non hai i privilegi necessari per accedere alla lista contatti';
$html_contact_none = 'È non stato trovato nessun contatto.';
$html_del_msg = 'Eliminare i messaggi selezionati ?';
$html_down_mail = 'Scarica';
$original_msg = '-- Messaggio originale --';
$to_empty = 'Il campo \'A\' non può essere vuoto!';
$html_images_warning = 'Per la vostra sicurezza, non vengono visualizzate immagini remote.';
$html_images_display = 'Mostra immagini';
$html_smtp_error_no_conn = 'Impossibile stabilire una connessione SMTP';
$html_smtp_error_unexpected = 'Risposta inattesa dal server SMTP:';
$lang_could_not_connect = 'Non è possibile connettersi al server';
$lang_invalid_msg_num = 'Numero messaggio errato';
$html_file_upload_attack = 'Possibile attacco tramite caricamento di files esterni';
$html_invalid_email_address = 'Indirizzo email non valido';
$html_invalid_msg_per_page = 'Numero di messaggi per pagina non valido';
$html_invalid_wrap_msg = 'Ampiezza testo a capo non valida';
$html_seperate_msg_win = 'Messaggi in finestre separate';
$html_err_file_contacts = 'Impossibile aprire in scrittura il file dei contatti.';
$html_session_file_error = 'Impossibile aprire in scrittura il file di sessione';
$html_login_not_allowed = 'Questo account non è autorizzato alla connessione.';
$lang_err_send_delay = 'È necessario attendere tra due messaggi di posta elettronica (%1$d secondi)';
$html_search = 'Ricerca';
$html_new_session = 'Sessione successiva';
$html_fd_filename = 'Scarica %1$s';
$html_fd_mailcount = '{{PLURAL:$1|0=Non ci sono messaggi|1=C\'è %1$d messaggio|Ci sono %1$d messaggi}} di posta elettronica nella cartella.';
$html_fd_mailskip = 'Le seguenti email non faranno parte del file mbox, poiché  superano il memory_limit del php:';
$html_fd_filesize = 'dimensione %1$d';
$html_fd_skipcount = 'con %1$d email';
$html_fd_largefolder = 'In base alla vostra velocità di scaricamento, questo download potrebbe non riuscire a causa di script time out.<br>Si prega di controllare il download per completezza o impostare un valore maggiore di max_execution_time nel php.ini.';
$reset_clicked = 'Vuoi veramente pulire questo modulo?';
$html_send_recover = 'Effettua l\'accesso per recuperare la bozza persa!';
$html_send_discard = 'Clicca qui per scartare la bozza salvata.';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/it.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: it.php 2664 2016-05-23 07:58:44Z siebrand $
 */
/** Italian (italiano)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Beta16
 * @author Darth Kule
 * @author Francesco Andreozzi <ozzo@lauratiamo.it>
 * @author Gianfranco
 * @author Guido Venturini <guido@technojuice.com>
 * @author Nastoshka
 * @author Rippitippi
 */

$lang_locale = 'it_IT.UTF-8';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Campo di login vuoto';
$err_passwd_empty = 'Non hai digitato la password';
$alt_delete = 'Elimina il messaggio selezionato';
$alt_delete_one = 'Elimina il messaggio';
$alt_new_msg = 'Nuovo messaggio';
$alt_reply = 'Rispondi al Mittente';
$alt_reply_all = 'Rispondi a tutti';
$alt_forward = 'Inoltra';
$alt_next = 'Prossimo';
$alt_prev = 'Precedente';
$title_next_page = 'Pagina successiva';
$title_prev_page = 'Pagina precedente';
$title_next_msg = 'Prossimo';
$title_prev_msg = 'Precedente';
$html_theme_label = 'Tema:';
$html_welcome = 'Benvenuto su %1$s';
$html_login = 'Accedi';
$html_user_label = 'Nome utente:';
$html_passwd_label = 'Password:';
$html_submit = 'Ok';
$html_help = 'Aiuto';
$html_server_label = 'Server:';
$html_wrong = 'Login o password non corretti';
$html_retry = 'Riprova';
$html_remember = 'Ricorda Impostazioni';
$html_lang_label = 'Lingua:';
$html_msgperpage_label = 'Messaggi per pagina:';
$html_preferences = 'Preferenze';
$html_full_name_label = 'Nome completo:';
$html_email_address_label = 'Indirizzo e-mail:';
$html_bccself = 'Manda una copia nascosta a me stesso';
$html_hide_addresses = 'Nascondi indirizzo';
$html_outlook_quoting = 'Quote Outlook-style';
$html_reply_to = 'Rispondi a';
$html_reply_to_label = 'Rispondi a:';
$html_use_signature = 'Usa la firma';
$html_signature = 'Firma';
$html_signature_label = 'Firma:';
$html_reply_leadin_label = 'Prefisso per risposte:';
$html_prefs_updated = 'Preferenze aggiornate';
$html_manage_folders_link = 'Configura Cartelle IMAP';
$html_manage_filters_link = 'Configura Filtri Email';
$html_use_graphical_smilies = 'Usa smilies grafici';
$html_sent_folder_label = 'Copia email inviate nella cartella predefinita';
$html_trash_folder_label = 'Sposta i messaggi cancellati nella cartella predefinita';
$html_colored_quotes = 'Citazioni a colori';
$html_display_struct = 'Mostra testo strutturato';
$html_send_html_mail = 'Invia messaggi in formato HTML';
$html_folders = 'Cartelle';
$html_folders_create_failed = 'La cartella non può essere creata!';
$html_folders_sub_failed = 'Impossibile connettersi alla cartella!';
$html_folders_unsub_failed = 'Impossibile disconnettersi dalla cartella!';
$html_folders_rename_failed = 'La cartella non può essere rinominata!';
$html_folders_updated = 'Cartelle aggiornate';
$html_folder_subscribe = 'Connettiti a';
$html_folder_rename = 'Rinomina';
$html_folder_create = 'Crea una nuova cartella con nome';
$html_folder_remove = 'Disconnettiti da';
$html_folder_delete = 'Elimina';
$html_folder_to = 'a';
$html_filter_remove = 'Cancella';
$html_filter_body = 'Corpo del messaggio';
$html_filter_subject = 'Soggetto';
$html_filter_to = 'Campo To';
$html_filter_cc = 'Campo Cc';
$html_filter_from = 'Campo From';
$html_filter_change_tip = 'Sovrascrivere direttamente un filtro per cambiarlo.';
$html_reapply_filters = 'Riapplica tutti i filtri';
$html_filter_contains = 'contiene';
$html_filter_name = 'Nome filtro';
$html_filter_action = 'Azione filtro';
$html_filter_moveto = 'Sposta in';
$html_select_one = '--Seleziona Uno--';
$html_and = 'e';
$html_new_msg_in = 'Nuovo messaggio in';
$html_or = 'o';
$html_move = 'Sposta';
$html_copy = 'Copia';
$html_messages_to = 'Messaggi selezionati in';
$html_gotopage = 'Vai alla pagina';
$html_gotofolder = 'Vai alla Cartella';
$html_other_folders = 'Lista Cartelle';
$html_page = 'Pagina';
$html_of = 'di';
$html_view_header = 'Mostra intestazione';
$html_remove_header = 'Nascondi intestazione';
$html_inbox = 'Posta in Arrivo';
$html_new_msg = 'Scrivi';
$html_reply = 'Rispondi';
$html_reply_short = 'Risposta:';
$html_reply_all = 'Rispondi a tutti';
$html_forward = 'Inoltra';
$html_forward_short = 'Inoltra:';
$html_forward_info = 'Il messaggio inoltrato sarà inviato come allegato a questo messaggio.';
$html_delete = 'Cancella';
$html_new = 'Nuovo';
$html_mark = 'Cancella';
$html_att_label = 'Allegato:';
$html_atts_label = 'Allegati:';
$html_unknown = '[sconosciuto]';
$html_part_x = 'Parte %s';
$html_attach = 'Allega';
$html_attach_forget = 'Devi allegare il file prima di inviare il messaggio !';
$html_attach_delete = 'Elimina i files selezionati';
$html_attach_none = 'Devi selezionare un file da allegare!';
$html_sort_by = 'Ordina per';
$html_sort = 'Ordina';
$html_from = 'da';
$html_from_label = 'Da:';
$html_subject = 'Oggetto';
$html_subject_label = 'Oggetto:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Invia';
$html_wrote = 'scritto';
$html_quote_wrote = 'Il %1$s %2$s, %3$s ha scritto:';
$html_size = 'Dimensione';
$html_totalsize = 'Dimensione totale';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nome del file';
$html_to = 'A';
$html_to_label = 'A:';
$html_cc = 'Per conoscenza';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Senza Oggetto';
$html_send = 'Invia';
$html_cancel = 'Annulla';
$html_no_mail = 'Non vi sono nuovi messaggi.';
$html_logout = 'Esci';
$html_msg = 'Messaggio';
$html_msgs = 'Messaggi';
$html_configuration = 'Questo server non è configurato correttamente!';
$html_priority = 'Priorità';
$html_priority_label = 'Priorità:';
$html_lowest = 'Più bassa';
$html_low = 'Bassa';
$html_normal = 'Normale';
$html_high = 'Alta';
$html_highest = 'Più alta';
$html_flagged = 'Segnato';
$html_spam = 'Spam';
$html_spam_warning = 'Questo messaggio è stato classificato come spam.';
$html_receipt = 'Richiedi conferma di recapito';
$html_select = 'Seleziona';
$html_select_all = 'Inverti Selezione';
$html_select_contacts = 'Selezionare i contatti';
$html_loading_image = 'Apertura immagine';
$html_send_confirmed = 'La tua e-mail è stata accettata per la consegna';
$html_no_sendaction = 'Nessuna azione specificata. Prova ad abilitare i JavaScript.';
$html_error_occurred = 'Si è verificato un errore';
$html_prefs_file_error = 'Impossibile aprire per la modifica il file delle preferenze.';
$html_wrap = 'Numero di caratteri per l\'andata a capo dei messaggi in uscita:';
$html_wrap_none = 'Nessuna andata a capo';
$html_usenet_separator = 'Separatore ("-- \n") prima della firma';
$html_mark_as = 'Contrassegna come';
$html_read = 'letto';
$html_unread = 'non letto';
$html_encoding_label = 'Codifica dei caratteri:';
$html_add = 'Nuovo';
$html_contacts = '%1$s Contatti';
$html_modify = 'Modifica';
$html_back = 'Indietro';
$html_contact_add = 'Aggiungi nuovo contatto';
$html_contact_mod = 'Modifica un contatto';
$html_contact_first = 'Nome';
$html_contact_last = 'Cognome';
$html_contact_nick = 'Nick';
$html_contact_mail = 'Email';
$html_contact_list = 'Lista dei Contatti di %1$s';
$html_contact_del = 'dalla lista dei contatti';
$html_contact_count = '%1$d Contatti';
$html_contact_err1 = 'Il numero massimo dei contatti è "%1$d"';
$html_contact_err2 = 'Non puoi aggiungere altri contatti';
$html_contact_err3 = 'Non hai i privilegi necessari per accedere alla lista contatti';
$html_contact_none = 'È non stato trovato nessun contatto.';
$html_contact_ruler_top = 'In alto';
$html_contact_listcheck_title = 'Seleziona per aggiungere e-mail a elenco.';
$html_contact_list_add = 'Aggiungi all\'elenco';
$html_contact_listname = 'Nome dell\'elenco';
$html_contact_listonly = 'Solo elenchi';
$html_contact_all = 'Mostra tutto';
$html_contact_add_confirm = 'Aggiungere i messaggi di posta elettronica a elenchi esistenti?';
$html_del_msg = 'Eliminare i messaggi selezionati ?';
$html_down_mail = 'Scarica';
$original_msg = '-- Messaggio originale --';
$to_empty = 'Il campo \'A\' non può essere vuoto!';
$html_images_warning = 'Per la vostra sicurezza, non vengono visualizzate immagini remote.';
$html_images_display = 'Mostra immagini';
$html_smtp_error_no_conn = 'Impossibile stabilire una connessione SMTP';
$html_smtp_error_unexpected = 'Risposta inattesa dal server SMTP:';
$lang_could_not_connect = 'Non è possibile connettersi al server';
$lang_invalid_msg_num = 'Numero messaggio errato';
$html_file_upload_attack = 'Possibile attacco tramite caricamento di files esterni';
$html_invalid_email_address = 'Indirizzo email non valido';
$html_invalid_msg_per_page = 'Numero di messaggi per pagina non valido';
$html_invalid_wrap_msg = 'Ampiezza testo a capo non valida';
$html_seperate_msg_win = 'Messaggi in finestre separate';
$html_err_file_contacts = 'Impossibile aprire in scrittura il file dei contatti.';
$html_session_file_error = 'Impossibile aprire in scrittura il file di sessione';
$html_login_not_allowed = 'Questo account non è autorizzato alla connessione.';
$lang_err_send_delay = 'È necessario attendere tra due messaggi di posta elettronica (%1$d secondi)';
$html_search = 'Ricerca';
$html_new_session = 'Sessione successiva';
$html_fd_filename = 'Scarica %1$s';
$html_fd_mailcount = '{{PLURAL:$1|0=Non ci sono messaggi|1=C\'è %1$d messaggio|Ci sono %1$d messaggi}} di posta elettronica nella cartella.';
$html_fd_mailskip = 'Le seguenti email non faranno parte del file mbox, poiché  superano il memory_limit del php:';
$html_fd_filesize = 'dimensione %1$d';
$html_fd_skipcount = 'con %1$d email';
$html_fd_largefolder = 'In base alla vostra velocità di scaricamento, questo download potrebbe non riuscire a causa di script time out.<br>Si prega di controllare il download per completezza o impostare un valore maggiore di max_execution_time nel php.ini.';
$reset_clicked = 'Vuoi veramente pulire questo modulo?';
$html_send_recover = 'Effettua l\'accesso per recuperare la bozza persa!';
$html_send_discard = 'Clicca qui per scartare la bozza salvata.';
$html_collect_label = 'Raccolta automatica indirizzi e-mail:';
$html_collect_option0 = 'Mai';
$html_collect_option1 = 'Solo per le email in uscita';
$html_collect_option2 = 'Solo per le email aperte';
$html_collect_option3 = 'Sempre';
